from .component import BipoleComponent


class Wire(BipoleComponent):

    type = 'W'
    args = ()
    sketch_net = 'W 1 2'
